# auto-Wizard101

This package provides utilities to help automate processes within Wizard101.
So far, the only supported automation is the auto-completion of the pet dance game.
See that example [here](https://github.com/GabeMillikan/auto-wizard101/blob/main/examples/autodance.py).